pub fn validate_bound_agent_snapshots(
bound_agents: &[BoundAgent],
) -> Result<(), BindingProviderError>Expand description
Validate a complete persisted binding snapshot without partially accepting any entry.
pub fn validate_bound_agent_snapshots(
bound_agents: &[BoundAgent],
) -> Result<(), BindingProviderError>Validate a complete persisted binding snapshot without partially accepting any entry.