LayerFactory

Type Alias LayerFactory 

pub type LayerFactory = Arc<dyn Fn(&Engine) -> Arc<dyn SpawnerLayer> + Send + Sync + 'static>;
Factory closure for a SpawnerLayer. The caller registers these at startup, and they are called with the engine context at bind time. Stateless layers can use |_engine| Arc::new(MyLayer); layers that need something like event_tx should do |engine| Arc::new(MyLayer::new(engine.event_tx())).

Aliased Type

pub struct LayerFactory { /* private fields */ }